#ifndef NEWINGREDIENTWINDOW_H
#define NEWINGREDIENTWINDOW_H

#include <QMainWindow>
#include <QtGui>
#include <QMaemo5ValueButton>
#include <QMaemo5ListPickSelector>
#include "xml.h"

class NewIngredientWindow : public QDialog
{
    Q_OBJECT
public:
    explicit NewIngredientWindow(QWidget *parent = 0);
    void load();
signals:

private:
    XML *xml;

    QPushButton *btnSave;
    QLineEdit *txtName;

    QMaemo5ValueButton *btnCarbohydrate;
    QMaemo5ListPickSelector *selectorCarbohydrate;
    QStandardItemModel *modelCarbohydrate;

    QMaemo5ValueButton *btnProtein;
    QMaemo5ListPickSelector *selectorProtein;
    QStandardItemModel *modelProtein;

    QMaemo5ValueButton *btnFat;
    QMaemo5ListPickSelector *selectorFat;
    QStandardItemModel *modelFat;

    QMaemo5ValueButton *btnType;
    QMaemo5ListPickSelector *selectorType;
    QStandardItemModel *modelType;

private slots:
    void save();
};

#endif // NEWINGREDIENTWINDOW_H
